sage-package: Utilities for authoring packages for SageMath
===========================================================

.. image:: https://readthedocs.org/projects/sage-package/badge/?version=latest
    :target: http://sage-package.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

This experimental package provides utilities for authoring SageMath
packages:

- sage_package.setuptools: utilities for the setup.py. At this stage,
  just a command for running tests.

- sage_package.sphinx: Sphinx theme and configuration to write and
  render documentation as in Sage.

For an example of use, see http://github.com/sagemath/sage_sample .
